@@ -20,16 +20,17 @@ void ftpTeardown();
 
 //-------------------------------------------------------
 
+const int DEFAULT_PORT_FTP = 21; //TLS enabled? => same for explicit FTP, but *implicit* FTP uses port 990
+
 struct FtpLogin
 {
     Zstring server;
-    int port = 0; // > 0 if set
+    int portCfg = 0; //use if > 0, DEFAULT_PORT_FTP otherwise
     Zstring username;
-    Zstring password;
+    std::optional<Zstring> password = Zstr(""); //none given => prompt during AFS::authenticateAccess()
     bool useTls = false;
-
     //other settings not specific to FTP session:
-    int timeoutSec = 15;
+    int timeoutSec = 10;
 };
 AfsDevice condenseToFtpDevice(const FtpLogin& login); //noexcept; potentially messy user input
 FtpLogin extractFtpLogin(const AfsDevice& afsDevice); //noexcept
