@@ -7,7 +7,7 @@
 #ifndef APPLICATION_H_081568741942010985702395
 #define APPLICATION_H_081568741942010985702395
 
-#include <vector>
+//#include <vector>
 #include <zen/zstring.h>
 #include <wx/app.h>
 #include "config.h"
@@ -25,9 +25,8 @@ private:
     wxLayoutDirection GetLayoutDirection() const override;
     void onEnterEventLoop();
 
-    void runGuiMode  (const Zstring& globalConfigFile);
-    void runGuiMode  (const Zstring& globalConfigFile, const XmlGuiConfig& guiCfg, const std::vector<Zstring>& cfgFilePaths, bool startComparison);
-    void runBatchMode(const Zstring& globalConfigFile, const XmlBatchConfig& batchCfg, const Zstring& cfgFilePath);
+    void runBatchMode(const FfsBatchConfig& batchCfg, const Zstring& cfgFilePath,
+                      GlobalConfig globalCfg, const Zstring& globalCfgFilePath);
 
     FfsExitCode exitCode_ = FfsExitCode::success;
 };
