@@ -335,14 +335,14 @@ std::wstring zen::formatCurlStatusCode(CURLcode sc)
             ZEN_CHECK_CASE_FOR_CONSTANT(CURLE_FTP_COULDNT_USE_REST);
             ZEN_CHECK_CASE_FOR_CONSTANT(CURLE_OBSOLETE32);
             ZEN_CHECK_CASE_FOR_CONSTANT(CURLE_RANGE_ERROR);
-            ZEN_CHECK_CASE_FOR_CONSTANT(CURLE_HTTP_POST_ERROR);
+            ZEN_CHECK_CASE_FOR_CONSTANT(CURLE_OBSOLETE34);
             ZEN_CHECK_CASE_FOR_CONSTANT(CURLE_SSL_CONNECT_ERROR);
             ZEN_CHECK_CASE_FOR_CONSTANT(CURLE_BAD_DOWNLOAD_RESUME);
             ZEN_CHECK_CASE_FOR_CONSTANT(CURLE_FILE_COULDNT_READ_FILE);
             ZEN_CHECK_CASE_FOR_CONSTANT(CURLE_LDAP_CANNOT_BIND);
             ZEN_CHECK_CASE_FOR_CONSTANT(CURLE_LDAP_SEARCH_FAILED);
             ZEN_CHECK_CASE_FOR_CONSTANT(CURLE_OBSOLETE40);
-            ZEN_CHECK_CASE_FOR_CONSTANT(CURLE_FUNCTION_NOT_FOUND);
+            ZEN_CHECK_CASE_FOR_CONSTANT(CURLE_OBSOLETE41);
             ZEN_CHECK_CASE_FOR_CONSTANT(CURLE_ABORTED_BY_CALLBACK);
             ZEN_CHECK_CASE_FOR_CONSTANT(CURLE_BAD_FUNCTION_ARGUMENT);
             ZEN_CHECK_CASE_FOR_CONSTANT(CURLE_OBSOLETE44);
