@@ -8,7 +8,6 @@
 #define SCOPE_GUARD_H_8971632487321434
 
 #include <cassert>
-//#include "type_traits.h"
 #include "legacy_compiler.h" //std::uncaught_exceptions
 
 //best of Zen, Loki and C++17
@@ -70,10 +69,10 @@ public:
     explicit ScopeGuard(const F&  fun) : fun_(fun) {}
     explicit ScopeGuard(      F&& fun) : fun_(std::move(fun)) {}
 
-    ScopeGuard(ScopeGuard&& tmp) :
-        fun_(std::move(tmp.fun_)),
-        exeptionCount_(tmp.exeptionCount_),
-        dismissed_(tmp.dismissed_) { tmp.dismissed_ = true; }
+    //ScopeGuard(ScopeGuard&& tmp) :
+    //    fun_(std::move(tmp.fun_)),
+    //    exeptionCount_(tmp.exeptionCount_),
+    //    dismissed_(tmp.dismissed_) { tmp.dismissed_ = true; }
 
     ~ScopeGuard() noexcept(runMode == ScopeGuardRunMode::onFail)
     {
